OperationMode

Enum OperationMode 

pub enum OperationMode<W: Word, const N: usize> {
    ECB,
    CBC {
        iv: [W; N],
    },
    CTR {
        nonce_and_counter: [W; N],
    },
}
Modes of operation for a block cipher.

  • ECB: Electronic Codebook mode.
  • CBC: Cipher Block Chaining mode.
  • CTR: Counter mode.

ECB mode of operation is less secure and is not recommended to use in production applications since it can be broken muc easily, special care should be kept while using this mode.

Variants



ECB

Electronic Codebook

Encrypt/Decrypt each block independently Without any additional security.



CBC

Cipher Block Chaining

Requires an initialization vector to add one stage enhanced security.

Fields



CTR

Counter

Requires a starting nonce + counter block, this way it adds two stage complexity over encryption/decryption.

Fields

nonce_and_counter: [W; N]