Version

Struct Version 

pub struct Version(/* private fields */);
RC5 version identifier

It represents RC5 control block parameters. These parameters are defined as follows:

  1. Algorithm version (1 for RC5)
  2. Word-size in bits
  3. Number of rounds.
  4. Key length in bytes.

This is how these parameters are arranged in version string:

RC5-v<Algorithm version>/<Word-size>/<Rounds>/<Key-length>

This can be useful when asserting what parametric version of RC5 to use for certain applications.

Implementations

Source

impl Version

pub fn from_parametric_vector(params: Vec<u8>) -> Self

Construct a new Version from a 4‑element parameter vector.

Expects the vector to be exactly four bytes: [algorithm, word_bits, rounds, key_bytes].

pub fn version(&self) -> String

Render the RC5 version string in the form: RC5-vA/B/C/D.

Where A,B,C,D correspond to the four parameters passed to new.