pub struct Version(/* private fields */);Expand description
RC5 version identifier
It represents RC5 control block parameters. These parameters are defined as follows:
- Algorithm version (1 for RC5)
- Word-size in bits
- Number of rounds.
- Key length in bytes.
This is how these parameters are arranged in version string:
RC5-v<Algorithm version>/<Word-size>/<Rounds>/<Key-length>
This can be useful when asserting what parametric version of RC5 to use for certain applications.
Implementations